Documentation
¶
Index ¶
Constants ¶
const (
// DefaultBaseURL is the public Yunxiao OpenAPI host used by the Node reference server.
DefaultBaseURL = "https://openapi-rdc.aliyuncs.com"
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type StaticConfig ¶
type StaticConfig struct {
Port int `mapstructure:"port"`
SSEBaseURL string `mapstructure:"sse_base_url"`
LogLevel string `mapstructure:"log_level"`
BaseURL string `mapstructure:"base_url"`
AccessToken string `mapstructure:"access_token"`
InsecureSkipTLSVerify bool `mapstructure:"insecure_skip_tls_verify"`
ReadOnly bool `mapstructure:"read_only"`
EnabledTools []string `mapstructure:"enabled_tools"`
DisabledTools []string `mapstructure:"disabled_tools"`
EnabledDomains []string `mapstructure:"enabled_domains"`
DisabledDomains []string `mapstructure:"disabled_domains"`
CompactMode bool `mapstructure:"compact"`
RequestTimeoutSeconds int `mapstructure:"request_timeout_seconds"`
}
StaticConfig contains configuration that is fixed when the server starts.
func LoadConfig ¶
func LoadConfig(configPath string, v *viper.Viper) (*StaticConfig, error)
LoadConfig loads configuration from defaults, optional YAML, environment, and flags.
func (*StaticConfig) GetPortString ¶
func (c *StaticConfig) GetPortString() string
GetPortString returns the configured HTTP listen address.
func (*StaticConfig) Validate ¶
func (c *StaticConfig) Validate() error
Validate checks whether the configuration can be used to start the server.
Click to show internal directories.
Click to hide internal directories.